"""
lcr is the lcr meter driver.

Use lcr.open to connect to a connected digital multi meter
Functions are dictacted by the metaclass in helper.py

"""
from fixate.drivers.lcr.helper import open, LCR, TestResult
